Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1190)

Unified Diff: chrome/browser/chromeos/policy/browser_policy_connector_chromeos.cc

Issue 2891453006: Check DeviceSettingsService is intialized before using. (Closed)
Patch Set: update comment Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/policy/browser_policy_connector_chromeos.cc
diff --git a/chrome/browser/chromeos/policy/browser_policy_connector_chromeos.cc b/chrome/browser/chromeos/policy/browser_policy_connector_chromeos.cc
index 1fd7393b3901408a43467f76d5f0bb8ae4329fa3..01851ee825b10ebf52f874acd9a770b754a5cd7d 100644
--- a/chrome/browser/chromeos/policy/browser_policy_connector_chromeos.cc
+++ b/chrome/browser/chromeos/policy/browser_policy_connector_chromeos.cc
@@ -88,12 +88,14 @@ BrowserPolicyConnectorChromeOS::BrowserPolicyConnectorChromeOS()
g_testing_install_attributes = nullptr;
}
// SystemSaltGetter or DBusThreadManager may be uninitialized on unit tests.
// TODO(satorux): Remove SystemSaltGetter::IsInitialized() when it's ready
// (removing it now breaks tests). crbug.com/141016.
if (chromeos::SystemSaltGetter::IsInitialized() &&
- chromeos::DBusThreadManager::IsInitialized()) {
+ chromeos::DBusThreadManager::IsInitialized() &&
+ chromeos::DeviceSettingsService::IsInitialized()) {
// Don't initialize install attributes if g_testing_install_attributes have
// been injected.
if (!install_attributes_) {
@@ -88,12 +88,14 @@ BrowserPolicyConnectorChromeOS::BrowserPolicyConnectorChromeOS()
g_testing_install_attributes = nullptr;
}
- // SystemSaltGetter or DBusThreadManager may be uninitialized on unit tests.
+ // SystemSaltGetter, DBusThreadManager or DeviceSettingsService may be
+ // uninitialized on unit tests.
// TODO(satorux): Remove SystemSaltGetter::IsInitialized() when it's ready
// (removing it now breaks tests). crbug.com/141016.
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698